# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class GeoTIFFOverlay(Component):
    """A GeoTIFFOverlay component.
GeoTIFFOverlay is just wrapper of LeafletGeoTIFFOverlay.

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): The children of this component
- url (string; optional): The URL of the GeoTIFF file. Only EPSG:4326 / WGS84 coordinates are supported at
this time, ie. the file will be mapped without reprojection.
- band (number; optional): The band inside the GeoTIFF file. Defaults to 0.
- image (number; optional): The image inside the GeoTIFF file. Defaults to 0.
- colorscale (string | list of strings; optional): Chroma-js colorscale. Either a colorscale name, e.g. "Viridis", or a list of colors,
e.g. ["black", "#fdd49e", "rgba(255,0,0,0.35)"]
The predefined colorscales are listed here:
https://github.com/gka/chroma.js/blob/master/src/colors/colorbrewer.js
- domainMin (number; optional): Domain minimum of the colorscale. Translates to the first color of the colorscale.
- domainMax (number; optional): Domain maximum of the colorscale. Translates to the last color of the colorscale.
- clampHigh (boolean; optional): Clamp values higher than domainMax to domainMax. Defaults to false, which precludes
those values from being drawn.
- clampLow (boolean; optional): Clamp values lower than domainMin to domainMin. Defaults to false, which precludes
those values from being drawn.
- classes (number | list of numbers; optional): The number or positions of discrete classes in the colorbar. If not set the
colorbar will be continuous, which is the default.
- clip (list of list of list of numbersss; optional): List of clipping polygons. Each polygon is a list of [lat, lon] coordinates that surrounds the area to be
shown on the map.
- style (dict; optional): HTML style object to add to the overlay entity, e.g. to set interpolation mode
with {'image-rendering': 'pixelated'}
- tileSize (number; optional): Width and height of tiles in the grid. Use a number if width and
height are equal, or L.point(width, height) otherwise.
- opacity (number; optional): Opacity of the tiles. Can be used in the createTile() function.
- updateWhenIdle (boolean; optional): Load new tiles only when panning ends. true by default on mobile
browsers, in order to avoid too many requests and keep smooth
navigation. false otherwise in order to display new tiles during
panning, since it is easy to pan outside the keepBuffer option
in desktop browsers.
- updateWhenZooming (boolean; optional): By default, a smooth zoom animation (during a touch zoom or a
flyTo()) will update grid layers every integer zoom level.
Setting this option to false will update the grid layer only
when the smooth animation ends.
- updateInterval (number; optional): Tiles will not update more than once every updateInterval
milliseconds when panning.
- zIndex (number; optional): The explicit zIndex of the tile layer.
- bounds (list of numbers; optional): If set, tiles will only be loaded inside the set LatLngBounds.
- minZoom (number; optional): The minimum zoom level down to which this layer will be
displayed (inclusive).
- maxZoom (number; optional): The maximum zoom level up to which this layer will be
displayed (inclusive).
- minNativeZoom (number; optional): Minimum zoom number the tile source has available. If it
is specified, the tiles on all zoom levels lower than
minNativeZoom will be loaded from minNativeZoom level
and auto-scaled.
- maxNativeZoom (number; optional): Maximum zoom number the tile source has available. If it
is specified, the tiles on all zoom levels higher than
maxNativeZoom will be loaded from maxNativeZoom level
and auto-scaled.
- noWrap (boolean; optional): Whether the layer is wrapped around the antimeridian. If
true, the GridLayer will only be displayed once at low zoom
levels. Has no effect when the map CRS doesn't wrap around.
Can be used in combination with bounds to prevent requesting
tiles outside the CRS limits.
- className (string; optional): A custom class name to assign to the tile layer. Empty by default.
- keepBuffer (number; optional): When panning the map, keep this many rows and columns of tiles
before unloading them.
- interactive (boolean; optional): If true, the image overlay will emit mouse events when clicked or hovered.
- bubblingMouseEvents (boolean; optional): When true, a mouse event on this path will trigger the same
event on the map (unless L.DomEvent.stopPropagation is used).
- id (string; optional): The ID used to identify this component in Dash callbacks
- pane (string; optional): The leaflet pane of the component
- attribution (string; optional): The attribution string for the component
- click_lat_lng_val (list of numbers; optional): Dash callback property. Receives [lat, lng, val] upon click. Requires interactive=True.
- click_lat_lng_idx (list of numbers; optional): Dash callback property. Receives [lat, lng, idx] upon click. Requires interactive=True.
- dbl_click_lat_lng_val (list of numbers; optional): Dash callback property. Receives [lat, lng, val] upon double click. Requires interactive=True.
- dbl_click_lat_lng_idx (list of numbers; optional): Dash callback property. Receives [lat, lng, idx] upon double click. Requires interactive=True."""
    @_explicitize_args
    def __init__(self, children=None, url=Component.UNDEFINED, band=Component.UNDEFINED, image=Component.UNDEFINED, colorscale=Component.UNDEFINED, domainMin=Component.UNDEFINED, domainMax=Component.UNDEFINED, clampHigh=Component.UNDEFINED, clampLow=Component.UNDEFINED, classes=Component.UNDEFINED, clip=Component.UNDEFINED, style=Component.UNDEFINED, tileSize=Component.UNDEFINED, opacity=Component.UNDEFINED, updateWhenIdle=Component.UNDEFINED, updateWhenZooming=Component.UNDEFINED, updateInterval=Component.UNDEFINED, zIndex=Component.UNDEFINED, bounds=Component.UNDEFINED, minZoom=Component.UNDEFINED, maxZoom=Component.UNDEFINED, minNativeZoom=Component.UNDEFINED, maxNativeZoom=Component.UNDEFINED, noWrap=Component.UNDEFINED, className=Component.UNDEFINED, keepBuffer=Component.UNDEFINED, interactive=Component.UNDEFINED, bubblingMouseEvents=Component.UNDEFINED, id=Component.UNDEFINED, pane=Component.UNDEFINED, attribution=Component.UNDEFINED, click_lat_lng_val=Component.UNDEFINED, click_lat_lng_idx=Component.UNDEFINED, dbl_click_lat_lng_val=Component.UNDEFINED, dbl_click_lat_lng_idx=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'url', 'band', 'image', 'colorscale', 'domainMin', 'domainMax', 'clampHigh', 'clampLow', 'classes', 'clip', 'style', 'tileSize', 'opacity', 'updateWhenIdle', 'updateWhenZooming', 'updateInterval', 'zIndex', 'bounds', 'minZoom', 'maxZoom', 'minNativeZoom', 'maxNativeZoom', 'noWrap', 'className', 'keepBuffer', 'interactive', 'bubblingMouseEvents', 'id', 'pane', 'attribution', 'click_lat_lng_val', 'click_lat_lng_idx', 'dbl_click_lat_lng_val', 'dbl_click_lat_lng_idx']
        self._type = 'GeoTIFFOverlay'
        self._namespace = 'dash_leaflet'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'url', 'band', 'image', 'colorscale', 'domainMin', 'domainMax', 'clampHigh', 'clampLow', 'classes', 'clip', 'style', 'tileSize', 'opacity', 'updateWhenIdle', 'updateWhenZooming', 'updateInterval', 'zIndex', 'bounds', 'minZoom', 'maxZoom', 'minNativeZoom', 'maxNativeZoom', 'noWrap', 'className', 'keepBuffer', 'interactive', 'bubblingMouseEvents', 'id', 'pane', 'attribution', 'click_lat_lng_val', 'click_lat_lng_idx', 'dbl_click_lat_lng_val', 'dbl_click_lat_lng_idx']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(GeoTIFFOverlay, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class GeoJSON(Component):
    """A GeoJSON component.
LayerGroup is a wrapper of LayerGroup in react-leaflet.
It takes similar properties to its react-leaflet counterpart.

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): Children
- geojsonOptions (dict; optional): Options for the GeoJSON object (see https://leafletjs.com/reference-1.6.0.html#geojson-option for details).
- cluster (boolean; default False): If true, marker clustering will be performed.
- clusterToLayer (string; optional): Function that determines how a cluster is drawn.
- zoomToClusterOnClick (boolean; default True): If true, zoom to cluster on click.
- spiderfyOnMaxZoom (boolean; default True): If true, markers that are not resolved at max zoom level will be spiderfied on click.
- superClusterOptions (dict; optional): Options for the SuperCluster object (see https://github.com/mapbox/supercluster for details).
- data (dict | string; optional): Data (consider using url for better performance).
- url (string; optional): Url to data (use instead of data for better performance).
- format (a value equal to: "geojson", "geobuf"; default "geojson"): Data format.
- hoverStyle (string; optional): Style function applied on hover.
- id (string; optional): The ID used to identify this component in Dash callbacks
- n_clicks (number; default 0): Dash callback property. Number of times the object has been clicked.
- featureClick (dict; optional): Last feature clicked.
- featureClickBounds (dict; optional): Bounds of last feature clicked.
- featureHover (dict; optional): Last feature hovered.
- featureHoverBounds (dict; optional): Bounds of last feature hovered."""
    @_explicitize_args
    def __init__(self, children=None, geojsonOptions=Component.UNDEFINED, cluster=Component.UNDEFINED, clusterToLayer=Component.UNDEFINED, zoomToClusterOnClick=Component.UNDEFINED, spiderfyOnMaxZoom=Component.UNDEFINED, superClusterOptions=Component.UNDEFINED, data=Component.UNDEFINED, url=Component.UNDEFINED, format=Component.UNDEFINED, hoverStyle=Component.UNDEFINED, id=Component.UNDEFINED, n_clicks=Component.UNDEFINED, featureClick=Component.UNDEFINED, featureClickBounds=Component.UNDEFINED, featureHover=Component.UNDEFINED, featureHoverBounds=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'geojsonOptions', 'cluster', 'clusterToLayer', 'zoomToClusterOnClick', 'spiderfyOnMaxZoom', 'superClusterOptions', 'data', 'url', 'format', 'hoverStyle', 'id', 'n_clicks', 'featureClick', 'featureClickBounds', 'featureHover', 'featureHoverBounds']
        self._type = 'GeoJSON'
        self._namespace = 'dash_leaflet'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'geojsonOptions', 'cluster', 'clusterToLayer', 'zoomToClusterOnClick', 'spiderfyOnMaxZoom', 'superClusterOptions', 'data', 'url', 'format', 'hoverStyle', 'id', 'n_clicks', 'featureClick', 'featureClickBounds', 'featureHover', 'featureHoverBounds']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(GeoJSON, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Colorbar(Component):
    """A Colorbar component.
Colorbar is just a wrapper of LeafletColorbar.

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): The children of this component
- position (string; optional): Position of the colorbar. One of 'topleft', 'topright', 'bottomleft', 'bottomright'
- colorscale (string | list of strings; optional): Chroma-js colorscale. Either a colorscale name, e.g. "Viridis", or a list of colors,
e.g. ["black", "#fdd49e", "rgba(255,0,0,0.35)"].
The predefined colorscales are listed here:
https://github.com/gka/chroma.js/blob/master/src/colors/colorbrewer.js
- width (number; optional): Width of the colorbar. If width > height then the colorbar will be in horizontal mode.
- height (number; optional): Height of the colorbar. If height > width then the colorbar will be in vertical mode.
- min (number; optional): Domain minimum of the colorbar. Translates to the first color of the colorscale.
- max (number; optional): Domain maximum of the colorbar. Translates to the last color of the colorscale.
- classes (number | list of numbers; optional): The number or positions of discrete classes in the colorbar. If not set the 
colorbar will be continuous, which is the default.
- unit (string; optional): Optional text to append to the colorbar ticks.
- nTicks (number; optional): Number of ticks on the colorbar.
- tickDecimals (number; optional): If set, fixes the tick decimal points to the given number.
- tickValues (list of numbers; optional): If set, these values are used for ticks (rather than the ones genrated based on nTicks).
- tickText (list of strings; optional): If set, this text will be used instead of the data values.
- tooltip (boolean; optional): If true, the value will be shown as tooltip on hover.
- opacity (number; optional): Opacity of the colorbar. Use it to match the perceived colors from an overlay 
with opacity.
- style (dict; optional): HTML style object to add to the colorbar entity, e.g. to set font color.
- id (string; optional): The ID used to identify this component in Dash callbacks
- className (string; optional): The class of the component"""
    @_explicitize_args
    def __init__(self, children=None, position=Component.UNDEFINED, colorscale=Component.UNDEFINED, width=Component.UNDEFINED, height=Component.UNDEFINED, min=Component.UNDEFINED, max=Component.UNDEFINED, classes=Component.UNDEFINED, unit=Component.UNDEFINED, nTicks=Component.UNDEFINED, tickDecimals=Component.UNDEFINED, tickValues=Component.UNDEFINED, tickText=Component.UNDEFINED, tooltip=Component.UNDEFINED, opacity=Component.UNDEFINED, style=Component.UNDEFINED, id=Component.UNDEFINED, className=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'position', 'colorscale', 'width', 'height', 'min', 'max', 'classes', 'unit', 'nTicks', 'tickDecimals', 'tickValues', 'tickText', 'tooltip', 'opacity', 'style', 'id', 'className']
        self._type = 'Colorbar'
        self._namespace = 'dash_leaflet'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'position', 'colorscale', 'width', 'height', 'min', 'max', 'classes', 'unit', 'nTicks', 'tickDecimals', 'tickValues', 'tickText', 'tooltip', 'opacity', 'style', 'id', 'className']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Colorbar, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Popup(Component):
    """A Popup component.
Popup is a wrapper of Popup in react-leaflet.
It takes similar properties to its react-leaflet counterpart.

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): The children of this component
- position (list of numbers; optional): A geographical point (lat, lon)
- maxWidth (number; optional): Max width of the popup, in pixels.
- minWidth (number; optional): Min width of the popup, in pixels.
- maxHeight (number; optional): If set, creates a scrollable container of the given height
inside a popup if its content exceeds it.
- autoPan (boolean; optional): Set it to false if you don't want the map to do panning 
animation to fit the opened popup.
- autoPanPaddingTopLeft (dict; optional): The margin between the popup and the top left corner of the map 
view after autopanning was performed.
- autoPanPaddingBottomRight (dict; optional): The margin between the popup and the bottom right corner of the
map view after autopanning was performed.
- autoPanPadding (dict; optional): Equivalent of setting both top left and bottom right autopan padding 
to the same value.
- keepInView (boolean; optional): Set it to true if you want to prevent users from panning the popup 
off of the screen while it is open.
- closeButton (boolean; optional): Controls the presence of a close button in the popup.
- autoClose (boolean; optional): Set it to false if you want to override the default behavior of the popup 
closing when another popup is opened.
- closeOnEscapeKey (boolean; optional): Set it to false if you want to override the default behavior of the ESC 
key for closing of the popup.
- closeOnClick (boolean; optional): Set it if you want to override the default behavior of the popup closing 
when user clicks on the map. Defaults to the map's closePopupOnClick option.
- id (string; optional): The ID used to identify this component in Dash callbacks
- className (string; optional): The class of the component (dynamic)
- pane (string; optional): The leaflet pane of the component
- attribution (string; optional): The attribution string for the component (dynamic)"""
    @_explicitize_args
    def __init__(self, children=None, position=Component.UNDEFINED, maxWidth=Component.UNDEFINED, minWidth=Component.UNDEFINED, maxHeight=Component.UNDEFINED, autoPan=Component.UNDEFINED, autoPanPaddingTopLeft=Component.UNDEFINED, autoPanPaddingBottomRight=Component.UNDEFINED, autoPanPadding=Component.UNDEFINED, keepInView=Component.UNDEFINED, closeButton=Component.UNDEFINED, autoClose=Component.UNDEFINED, closeOnEscapeKey=Component.UNDEFINED, closeOnClick=Component.UNDEFINED, id=Component.UNDEFINED, className=Component.UNDEFINED, pane=Component.UNDEFINED, attribution=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'position', 'maxWidth', 'minWidth', 'maxHeight', 'autoPan', 'autoPanPaddingTopLeft', 'autoPanPaddingBottomRight', 'autoPanPadding', 'keepInView', 'closeButton', 'autoClose', 'closeOnEscapeKey', 'closeOnClick', 'id', 'className', 'pane', 'attribution']
        self._type = 'Popup'
        self._namespace = 'dash_leaflet'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'position', 'maxWidth', 'minWidth', 'maxHeight', 'autoPan', 'autoPanPaddingTopLeft', 'autoPanPaddingBottomRight', 'autoPanPadding', 'keepInView', 'closeButton', 'autoClose', 'closeOnEscapeKey', 'closeOnClick', 'id', 'className', 'pane', 'attribution']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Popup, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class SuperCluster(Component):
    """A SuperCluster component.
LayerGroup is a wrapper of LayerGroup in react-leaflet.
It takes similar properties to its react-leaflet counterpart.

Keyword arguments:
- data (dict | string; optional): Data (consider using url for better performance).
- url (string; optional): Url to data (use instead of data for better performance).
- format (a value equal to: "geojson", "geobuf"; default "geojson"): Data format.
- zoomToBoundsOnClick (boolean; default True): If true, zoom on cluster click.
- spiderfyOnMaxZoom (boolean; default True): If true, marker that are not resolved at max zoom level will be spiderfied on click.
- spiderfyOptions (dict; default {
    spiderfyDistanceMultiplier: 1,
    spiderLegPolylineOptions: {weight: 1.5, color: '#222', opacity: 0.5},
}): Options passed to SuperCluster, https://github.com/mapbox/supercluster. spiderfyOptions has the following type: dict containing keys 'spiderfyDistanceMultiplier', 'spiderLegPolylineOptions'.
Those keys have the following types:
  - spiderfyDistanceMultiplier (number; optional)
  - spiderLegPolylineOptions (dict; optional)
- superclusterOptions (dict; optional): Options passed to SuperCluster, https://github.com/mapbox/supercluster.
- clusterOptions (dict; default {
    iconSize: 40,
    classNames: [
        {minCount: 0, className: "marker-cluster marker-cluster-small"},
        {minCount: 100, className: "marker-cluster marker-cluster-medium"},
        {minCount: 1000, className: "marker-cluster marker-cluster-large"},
    ]
}): Option for customization of the clusters. clusterOptions has the following type: dict containing keys 'iconSize', 'classNames'.
Those keys have the following types:
  - iconSize (number; optional)
  - classNames (dict; optional): classNames has the following type: list of dicts containing keys 'minCount', 'className'.
Those keys have the following types:
  - minCount (number; optional)
  - className (string; optional)
- id (string; optional): The ID used to identify this component in Dash callbacks
- n_clicks (number; default 0): Dash callback property. Number of times the marker has been clicked
- featureClick (dict; optional): Last feature clicked.
- featureHover (dict; optional): Last feature hover."""
    @_explicitize_args
    def __init__(self, data=Component.UNDEFINED, url=Component.UNDEFINED, format=Component.UNDEFINED, zoomToBoundsOnClick=Component.UNDEFINED, spiderfyOnMaxZoom=Component.UNDEFINED, spiderfyOptions=Component.UNDEFINED, superclusterOptions=Component.UNDEFINED, clusterOptions=Component.UNDEFINED, id=Component.UNDEFINED, n_clicks=Component.UNDEFINED, featureClick=Component.UNDEFINED, featureHover=Component.UNDEFINED, **kwargs):
        self._prop_names = ['data', 'url', 'format', 'zoomToBoundsOnClick', 'spiderfyOnMaxZoom', 'spiderfyOptions', 'superclusterOptions', 'clusterOptions', 'id', 'n_clicks', 'featureClick', 'featureHover']
        self._type = 'SuperCluster'
        self._namespace = 'dash_leaflet'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['data', 'url', 'format', 'zoomToBoundsOnClick', 'spiderfyOnMaxZoom', 'spiderfyOptions', 'superclusterOptions', 'clusterOptions', 'id', 'n_clicks', 'featureClick', 'featureHover']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(SuperCluster, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DivMarker(Component):
    """A DivMarker component.
Marker is a wrapper of Marker in react-leaflet.
It takes similar properties to its react-leaflet counterpart.

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): The children of this component
- position (list of numbers; required): A geographical point (lat, lon)
- iconOptions (dict; optional): Options passed to DivIcon constructor. iconOptions has the following type: dict containing keys 'iconSize', 'iconAnchor', 'popupAnchor', 'className', 'html'.
Those keys have the following types:
  - iconSize (list of numbers; optional)
  - iconAnchor (list of numbers; optional)
  - popupAnchor (list of numbers; optional)
  - className (list of numbers; optional)
  - html (string; optional)
- draggable (boolean; optional): Whether the marker is draggable with mouse/touch or not.
- opacity (number; optional): The opacity of the marker.
- zIndexOffset (number; optional): By default, marker images zIndex is set automatically based
on its latitude. Use this option if you want to put the
marker on top of all others (or below), specifying a high
value like 1000 (or high negative value, respectively).
- keyboard (boolean; optional): Whether the marker can be tabbed to with a keyboard and clicked by
pressing enter.
- title (string; optional): Text for the browser tooltip that appear on marker hover (no tooltip
by default).
- alt (string; optional): Text for the alt attribute of the icon image (useful for accessibility).
- riseOnHover (boolean; optional): If true, the marker will get on top of others when you hover the mouse
over it.
- riseOffset (number; optional): The z-index offset used for the riseOnHover feature.
- bubblingMouseEvents (boolean; optional): When true, a mouse event on this marker will trigger the same event
on the map (unless L.DomEvent.stopPropagation is used).
- autoPan (boolean; optional): Whether to pan the map when dragging this marker near its edge or not.
- autoPanPadding (dict; optional): Distance (in pixels to the left/right and to the top/bottom) of the map
edge to start panning the map.
- autoPanSpeed (number; optional): Number of pixels the map should pan by.
- interactive (boolean; optional): If false, the layer will not emit mouse events and will act as a part of
the underlying map.
- id (string; optional): The ID used to identify this component in Dash callbacks
- pane (string; optional): The leaflet pane of the component
- attribution (string; optional): The attribution string for the component
- n_clicks (number; default 0): Dash callback property. Number of times the object has been clicked"""
    @_explicitize_args
    def __init__(self, children=None, position=Component.REQUIRED, iconOptions=Component.UNDEFINED, draggable=Component.UNDEFINED, opacity=Component.UNDEFINED, zIndexOffset=Component.UNDEFINED, keyboard=Component.UNDEFINED, title=Component.UNDEFINED, alt=Component.UNDEFINED, riseOnHover=Component.UNDEFINED, riseOffset=Component.UNDEFINED, bubblingMouseEvents=Component.UNDEFINED, autoPan=Component.UNDEFINED, autoPanPadding=Component.UNDEFINED, autoPanSpeed=Component.UNDEFINED, interactive=Component.UNDEFINED, id=Component.UNDEFINED, pane=Component.UNDEFINED, attribution=Component.UNDEFINED, n_clicks=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'position', 'iconOptions', 'draggable', 'opacity', 'zIndexOffset', 'keyboard', 'title', 'alt', 'riseOnHover', 'riseOffset', 'bubblingMouseEvents', 'autoPan', 'autoPanPadding', 'autoPanSpeed', 'interactive', 'id', 'pane', 'attribution', 'n_clicks']
        self._type = 'DivMarker'
        self._namespace = 'dash_leaflet'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'position', 'iconOptions', 'draggable', 'opacity', 'zIndexOffset', 'keyboard', 'title', 'alt', 'riseOnHover', 'riseOffset', 'bubblingMouseEvents', 'autoPan', 'autoPanPadding', 'autoPanSpeed', 'interactive', 'id', 'pane', 'attribution', 'n_clicks']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['position']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(DivMarker, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class PolylineDecorator(Component):
    """A PolylineDecorator component.
Polyline is a wrapper of Polyline in react-leaflet.
It takes similar properties to its react-leaflet counterpart.

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): The children of this component. If positions are not specified, an attempt is made to read them from the
children property. In this case, the children must be a single PolyLine or a single Polygon.
- positions (list of list of numberss | list of list of list of numbersss; optional): An array of geographical points (lat, lon)
- patterns (dict; optional): List of patterns to be added. patterns has the following type: list of dicts containing keys 'offset', 'endOffset', 'repeat', 'dash', 'arrowHead', 'marker'.
Those keys have the following types:
  - offset (string; optional)
  - endOffset (string; optional)
  - repeat (string; optional)
  - dash (dict; optional): dash has the following type: dict containing keys 'pixelSize', 'pathOptions'.
Those keys have the following types:
  - pixelSize (number; optional)
  - pathOptions (dict; optional)
  - arrowHead (dict; optional): arrowHead has the following type: dict containing keys 'polygon', 'pixelSize', 'headAngle', 'pathOptions'.
Those keys have the following types:
  - polygon (boolean; optional)
  - pixelSize (number; optional)
  - headAngle (number; optional)
  - pathOptions (dict; optional)
  - marker (dict; optional): marker has the following type: dict containing keys 'markerOptions', 'rotate'.
Those keys have the following types:
  - markerOptions (dict; optional)
  - rotate (boolean; optional)
- id (string; optional): The ID used to identify this component in Dash callbacks"""
    @_explicitize_args
    def __init__(self, children=None, positions=Component.UNDEFINED, patterns=Component.UNDEFINED, id=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'positions', 'patterns', 'id']
        self._type = 'PolylineDecorator'
        self._namespace = 'dash_leaflet'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'positions', 'patterns', 'id']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(PolylineDecorator, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Rectangle(Component):
    """A Rectangle component.
Rectangle is a wrapper of Rectangle in react-leaflet.
It takes similar properties to its react-leaflet counterpart.

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): The children of this component
- bounds (list of list of numberss; required): An array of two geographical points (lat, lon)
- smoothFactor (number; optional): How much to simplify the polyline on each zoom level. More means better 
performance and smoother look, and less means more accurate representation.
- noClip (boolean; optional): Disable polyline clipping.
- stroke (boolean; optional): Whether to draw stroke along the path. Set it to false to disable borders 
on Rectangles or circles.
- color (string; optional): Stroke color
- weight (number; optional): Stroke width in pixels
- opacity (number; optional): Stroke opacity
- lineCap (string; optional): A string that defines shape to be used at the end of the stroke.
- lineJoin (string; optional): A string that defines shape to be used at the corners of the stroke.
- dashArray (string; optional): A string that defines the stroke dash pattern. Doesn't work on Canvas-powered 
layers in some old browsers.
- dashOffset (string; optional): A string that defines the distance into the dash pattern to start the dash. 
Doesn't work on Canvas-powered layers in some old browsers.
- fill (boolean; optional): Whether to fill the path with color. Set it to false to disable filling on 
Rectangles or circles.
- fillColor (string; optional): Fill color. Defaults to the value of the color option
- fillOpacity (number; optional): Fill opacity
- fillRule (string; optional): A string that defines how the inside of a shape is determined.
- bubblingMouseEvents (boolean; optional): When true, a mouse event on this path will trigger the same 
event on the map (unless L.DomEvent.stopPropagation is used).
- renderer (dict; optional): Use this specific instance of Renderer for this path. Takes 
precedence over the map's default renderer.
- className (string; optional): Custom class name set on an element. Only for SVG renderer.
- interactive (boolean; optional): If false, the layer will not emit mouse events and will act
as a part of the underlying map.
- id (string; optional): The ID used to identify this component in Dash callbacks
- pane (string; optional): The leaflet pane of the component
- attribution (string; optional): The attribution string for the component
- click_lat_lng (list of numbers; optional): Dash callback property. Receives [lat, lng] upon click.
- dbl_click_lat_lng (list of numbers; optional): Dash callback property. Receives [lat, lng] upon double click."""
    @_explicitize_args
    def __init__(self, children=None, bounds=Component.REQUIRED, smoothFactor=Component.UNDEFINED, noClip=Component.UNDEFINED, stroke=Component.UNDEFINED, color=Component.UNDEFINED, weight=Component.UNDEFINED, opacity=Component.UNDEFINED, lineCap=Component.UNDEFINED, lineJoin=Component.UNDEFINED, dashArray=Component.UNDEFINED, dashOffset=Component.UNDEFINED, fill=Component.UNDEFINED, fillColor=Component.UNDEFINED, fillOpacity=Component.UNDEFINED, fillRule=Component.UNDEFINED, bubblingMouseEvents=Component.UNDEFINED, renderer=Component.UNDEFINED, className=Component.UNDEFINED, interactive=Component.UNDEFINED, id=Component.UNDEFINED, pane=Component.UNDEFINED, attribution=Component.UNDEFINED, click_lat_lng=Component.UNDEFINED, dbl_click_lat_lng=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'bounds', 'smoothFactor', 'noClip', 'stroke', 'color', 'weight', 'opacity', 'lineCap', 'lineJoin', 'dashArray', 'dashOffset', 'fill', 'fillColor', 'fillOpacity', 'fillRule', 'bubblingMouseEvents', 'renderer', 'className', 'interactive', 'id', 'pane', 'attribution', 'click_lat_lng', 'dbl_click_lat_lng']
        self._type = 'Rectangle'
        self._namespace = 'dash_leaflet'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'bounds', 'smoothFactor', 'noClip', 'stroke', 'color', 'weight', 'opacity', 'lineCap', 'lineJoin', 'dashArray', 'dashOffset', 'fill', 'fillColor', 'fillOpacity', 'fillRule', 'bubblingMouseEvents', 'renderer', 'className', 'interactive', 'id', 'pane', 'attribution', 'click_lat_lng', 'dbl_click_lat_lng']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['bounds']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Rectangle, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class LayerGroup(Component):
    """A LayerGroup component.
LayerGroup is a wrapper of LayerGroup in react-leaflet.
It takes similar properties to its react-leaflet counterpart.

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): Attribution
- attribution (string; optional): Attribution
- className (string; optional): A custom class name to assign to the image. Empty by default.
- id (string; optional): The ID used to identify this component in Dash callbacks"""
    @_explicitize_args
    def __init__(self, children=None, attribution=Component.UNDEFINED, className=Component.UNDEFINED, id=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'attribution', 'className', 'id']
        self._type = 'LayerGroup'
        self._namespace = 'dash_leaflet'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'attribution', 'className', 'id']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(LayerGroup, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class TileLayer(Component):
    """A TileLayer component.
TileLayer is a wrapper of TileLayer in react-leaflet.
It takes similar properties to its react-leaflet counterpart.

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): The children of this component
- url (string; default "https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png"): A URL template for the tile layer, ie. a string of the following form:
'http://{s}.somedomain.com/blabla/{z}/{x}/{y}{r}.png'
where {s} means one of the available subdomains (used sequentially to 
help with browser parallel requests per domain limitation; subdomain 
values are specified in options; a, b or c by default, can be omitted), 
{z} zoom level, {x} and {y} tile coordinates. {r} can be used to
add "@2x" to the URL to load retina tiles.
- opacity (number; optional): Opacity of the tiles. Can be used in the createTile() function.
- zIndex (number; optional): The explicit zIndex of the tile layer.
- minZoom (number; optional): The minimum zoom level down to which this layer will be displayed (inclusive).
- maxZoom (number; optional): The maximum zoom level up to which this layer will be displayed (inclusive).
- subdomains (string; optional): Subdomains of the tile service. Can be passed in the form of one string 
(where each letter is a subdomain name) or an array of strings.
- errorTileUrl (string; optional): URL to the tile image to show in place of the tile that failed to load.
- zoomOffset (number; optional): The zoom number used in tile URLs will be offset with this value.
- tms (boolean; optional): If true, inverses Y axis numbering for tiles (turn this on for TMS services).
- zoomReverse (boolean; optional): If set to true, the zoom number used in tile URLs will be reversed 
(maxZoom - zoom instead of zoom)
- detectRetina (boolean; optional): If true and user is on a retina display, it will request four tiles of half 
the specified size and a bigger zoom level in place of one to utilize the 
high resolution.
- crossOrigin (boolean; optional): Whether the crossOrigin attribute will be added to the tiles. If 
a String is provided, all tiles will have its crossOrigin attribute 
set to the String provided. This is needed if you want to access tile 
pixel data. Refer to CORS Settings for valid String values.
- tileSize (number; optional): Width and height of tiles in the grid. Use a number if width and 
height are equal, or L.point(width, height) otherwise.
- updateWhenIdle (boolean; optional): Load new tiles only when panning ends. true by default on mobile 
browsers, in order to avoid too many requests and keep smooth 
navigation. false otherwise in order to display new tiles during 
panning, since it is easy to pan outside the keepBuffer option 
in desktop browsers.
- updateWhenZooming (boolean; optional): By default, a smooth zoom animation (during a touch zoom or a 
flyTo()) will update grid layers every integer zoom level. 
Setting this option to false will update the grid layer only 
when the smooth animation ends.
- updateInterval (number; optional): Tiles will not update more than once every updateInterval 
milliseconds when panning.
- bounds (list of numbers; optional): If set, tiles will only be loaded inside the set LatLngBounds.
- minNativeZoom (number; optional): Minimum zoom number the tile source has available. If it 
is specified, the tiles on all zoom levels lower than 
minNativeZoom will be loaded from minNativeZoom level 
and auto-scaled.
- maxNativeZoom (number; optional): Maximum zoom number the tile source has available. If it
is specified, the tiles on all zoom levels higher than 
maxNativeZoom will be loaded from maxNativeZoom level 
and auto-scaled.
- noWrap (boolean; optional): Whether the layer is wrapped around the antimeridian. If 
true, the GridLayer will only be displayed once at low zoom 
levels. Has no effect when the map CRS doesn't wrap around. 
Can be used in combination with bounds to prevent requesting 
tiles outside the CRS limits.
- className (string; optional): A custom class name to assign to the tile layer. Empty by default.
- keepBuffer (number; optional): When panning the map, keep this many rows and columns of tiles 
before unloading them.
- id (string; optional): The ID used to identify this component in Dash callbacks
- pane (string; optional): The leaflet pane of the component
- attribution (string; optional): The attribution string for the component"""
    @_explicitize_args
    def __init__(self, children=None, url=Component.UNDEFINED, opacity=Component.UNDEFINED, zIndex=Component.UNDEFINED, minZoom=Component.UNDEFINED, maxZoom=Component.UNDEFINED, subdomains=Component.UNDEFINED, errorTileUrl=Component.UNDEFINED, zoomOffset=Component.UNDEFINED, tms=Component.UNDEFINED, zoomReverse=Component.UNDEFINED, detectRetina=Component.UNDEFINED, crossOrigin=Component.UNDEFINED, tileSize=Component.UNDEFINED, updateWhenIdle=Component.UNDEFINED, updateWhenZooming=Component.UNDEFINED, updateInterval=Component.UNDEFINED, bounds=Component.UNDEFINED, minNativeZoom=Component.UNDEFINED, maxNativeZoom=Component.UNDEFINED, noWrap=Component.UNDEFINED, className=Component.UNDEFINED, keepBuffer=Component.UNDEFINED, id=Component.UNDEFINED, pane=Component.UNDEFINED, attribution=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'url', 'opacity', 'zIndex', 'minZoom', 'maxZoom', 'subdomains', 'errorTileUrl', 'zoomOffset', 'tms', 'zoomReverse', 'detectRetina', 'crossOrigin', 'tileSize', 'updateWhenIdle', 'updateWhenZooming', 'updateInterval', 'bounds', 'minNativeZoom', 'maxNativeZoom', 'noWrap', 'className', 'keepBuffer', 'id', 'pane', 'attribution']
        self._type = 'TileLayer'
        self._namespace = 'dash_leaflet'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'url', 'opacity', 'zIndex', 'minZoom', 'maxZoom', 'subdomains', 'errorTileUrl', 'zoomOffset', 'tms', 'zoomReverse', 'detectRetina', 'crossOrigin', 'tileSize', 'updateWhenIdle', 'updateWhenZooming', 'updateInterval', 'bounds', 'minNativeZoom', 'maxNativeZoom', 'noWrap', 'className', 'keepBuffer', 'id', 'pane', 'attribution']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(TileLayer, self).__init__(children=children, **args)



import json
import geobuf
import dash_leaflet as dl
import base64


def categorical_colorbar(*args, categories, colorscale, **kwargs):
    indices = list(range(len(categories) + 1))
    return dl.Colorbar(*args, min=0, max=len(categories), classes=indices, colorscale=colorscale, tooltip=False,
                       tickValues=[item + 0.5 for item in indices[:-1]], tickText=categories, **kwargs)


def markers_to_geojson(markers):
    geojson = {"type": "FeatureCollection", "features": []}
    for marker in markers:
        feature = {"type": "Feature", "geometry": {"type": "Point", "coordinates": [marker["lon"], marker["lat"]]}}
        props = [key for key in marker.keys() if key != "position"]
        if props:
            feature["properties"] = {prop: marker[prop] for prop in props}
        geojson["features"].append(feature)
    return geojson


def supercluster(markers, *args, **kwargs):
    geojson = markers_to_geojson(markers)
    # Convert to geobuf.
    pbf = geobuf.encode(geojson)
    content = base64.b64encode(pbf).decode()
    # Construc the cluster.
    return dl.SuperCluster(data=content, format="geobuf", *args, **kwargs)


def geojson(data, *args, style, **kwargs):
    feature_id = "id"
    # If id missing and/or not unique, a new id (this list index) is assigned (this is NOT recommended).
    if not _validate_feature_ids(data):
        feature_id = "dash_id"
        for i, f in enumerate(data["features"]):
            f[feature_id] = i
    # Setup style.
    feature_style = {f[feature_id]: style(f) for f in data["features"]}
    return dl.GeoJSON(*args, data=data, featureStyle=feature_style, featureId=feature_id, **kwargs)


def geojson_style(data, style):
    # If an id is there, use it.
    if _validate_feature_ids(data):
        return {f["id"]: style(f) for f in data["features"]}
    # Otherwise, use the list index.
    return {i: style(f) for i, f in enumerate(data["features"])}


def _validate_feature_ids(data):
    ids = [f["id"] for f in data["features"] if "id" in f]
    return len(list(set(ids))) == len(data["features"])



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Map(Component):
    """A Map component.
Map is a wrapper of Map in react-leaflet.
It takes similar properties to its react-leaflet counterpart.

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): The children of this component (dynamic)
- animate (boolean; optional): If true, panning will always be animated if possible. If false, it will not 
animate panning, either resetting the map view if panning more than a screen
away, or just setting a new offset for the map pane (except for panBy which 
always does the latter).
- duration (number; optional): Duration of animated panning, in seconds.
- easeLinearity (number; optional): Easing of the inertia
- noMoveStart (boolean; optional): If true, panning won't fire movestart event on start (used internally for panning 
inertia).
- bounds (list of list of numberss; optional): Sets a map view that contains the given geographical bounds with the maximum zoom 
level possible.
- boundsOptions (dict; optional): Object with the following entries:

paddingTopLeft: Sets the amount of padding in the top left corner of a map container 
                that shouldn't be accounted for when setting the view to fit bounds. 
                Useful if you have some control overlays on the map like a sidebar 
                and you don't want them to obscure objects you're zooming to.
paddingBottomRight: The same for the bottom right corner of the map.
padding: Equivalent of setting both top left and bottom right padding to the same value.
maxZoom: The maximum possible zoom to use.
- boxZoom (boolean; optional): Whether the map can be zoomed to a rectangular area specified by dragging 
the mouse while pressing the shift key.
- center (list of numbers; default [56, 10]): Sets the geographic center of the map
- doubleClickZoom (boolean | string; optional): Whether the map can be zoomed in by double clicking on it and zoomed out by 
double clicking while holding shift. If passed 'center', double-click zoom 
will zoom to the center of the view regardless of where the mouse was.
Defaults to true.
- dragging (boolean; optional): Whether the map be draggable with mouse/touch or not.
- keyboard (boolean; optional): Makes the map focusable and allows users to navigate the map with keyboard 
arrows and +/- keys.
- maxBounds (list of list of numberss; optional): When this option is set, the map restricts the view to the given geographical bounds, 
bouncing the user back if the user tries to pan outside the view. To set the 
restriction dynamically, use setMaxBounds method.
- scrollWheelZoom (boolean | string; optional): Whether the map can be zoomed by using the mouse wheel. If passed 'center', 
it will zoom to the center of the view regardless of where the mouse was.
- useFlyTo (boolean; optional): Boolean to control whether to use flyTo functions for bounds and center. 
If false map.fitBounds and map.setView will be used. If true map.flyToBounds 
and map.flyTo will be used. Defaults to false.
- tap (boolean; optional): Enables mobile hacks for supporting instant taps (fixing 200ms click delay on 
iOS/Android) and touch holds (fired as contextmenu events).
- touchZoom (dict; optional): Whether the map can be zoomed by touch-dragging with two fingers. If passed 
'center', it will zoom to the center of the view regardless of where the touch 
events (fingers) were. Enabled for touch-capable web browsers except for old 
Androids.
- viewport (dict; optional): Sets the viewport, which is an object containing 'center' and 'zoom'.
- zoom (number; default 6): Sets the map zoom level
- preferCanvas (boolean; optional): Whether Paths should be rendered on a Canvas renderer. By default,
all Paths are rendered in a SVG renderer.
- attributionControl (boolean; optional): Whether a attribution control is added to the map by default.
- zoomControl (boolean; optional): Whether a zoom control is added to the map by default.
- closePopupOnClick (boolean; optional): Set it to false if you don't want popups to close when user clicks the map.
- zoomSnap (number; optional): Forces the map's zoom level to always be a multiple of this, particularly
right after a fitBounds() or a pinch-zoom. By default, the zoom level 
snaps to the nearest integer; lower values (e.g. 0.5 or 0.1) allow for 
greater granularity. A value of 0 means the zoom level will not be snapped 
after fitBounds or a pinch-zoom.
- zoomDelta (number; optional): Controls how much the map's zoom level will change after a zoomIn(), 
zoomOut(), pressing + or - on the keyboard, or using the zoom controls. 
Values smaller than 1 (e.g. 0.5) allow for greater granularity.
- trackResize (boolean; optional): Whether the map automatically handles browser window resize to update itself.
- crs (dict; optional): The Coordinate Reference System to use. Don't change this if you're not sure 
what it means.
- minZoom (number; optional): Minimum zoom level of the map. If not specified and at least one GridLayer or 
TileLayer is in the map, the lowest of their minZoom options will be used instead.
- maxZoom (number; optional): Maximum zoom level of the map. If not specified and at least one GridLayer or 
TileLayer is in the map, the highest of their maxZoom options will be used instead.
- renderer (dict; optional): The default method for drawing vector layers on the map. L.SVG or L.Canvas by default 
depending on browser support.
- zoomAnimation (boolean; optional): Whether the map zoom animation is enabled. By default it's enabled in all browsers 
that support CSS3 Transitions except Android.
- zoomAnimationThreshold (number; optional): Won't animate zoom if the zoom difference exceeds this value.
- fadeAnimation (boolean; optional): Whether the tile fade animation is enabled. By default it's enabled in all browsers 
that support CSS3 Transitions except Android.
- markerZoomAnimation (boolean; optional): Whether markers animate their zoom with the zoom animation, if disabled they will 
disappear for the length of the animation. By default it's enabled in all browsers 
that support CSS3 Transitions except Android.
- transform3DLimit (number; optional): Defines the maximum size of a CSS translation transform. The default value should 
not be changed unless a web browser positions layers in the wrong place after doing 
a large panBy.
- inertia (boolean; optional): If enabled, panning of the map will have an inertia effect where the map builds 
momentum while dragging and continues moving in the same direction for some time. 
Feels especially nice on touch devices. Enabled by default unless running on old 
Android devices.
- inertiaDeceleration (number; optional): The rate with which the inertial movement slows down, in pixels/second.
- inertiaMaxSpeed (number; optional): Max speed of the inertial movement, in pixels/second.
- worldCopyJump (boolean; optional): With this option enabled, the map tracks when you pan to another "copy" of 
the world and seamlessly jumps to the original one so that all overlays like 
markers and vector layers are still visible.
- maxBoundsViscosity (number; optional): If maxBounds is set, this option will control how solid the bounds are when 
dragging the map around. The default value of 0.0 allows the user to drag 
outside the bounds at normal speed, higher values will slow down map dragging 
outside bounds, and 1.0 makes the bounds fully solid, preventing the user from 
dragging outside the bounds.
- keyboardPanDelta (number; optional): Amount of pixels to pan when pressing an arrow key.
- wheelDebounceTime (number; optional): Limits the rate at which a wheel can fire (in milliseconds). By default user 
can't zoom via wheel more often than once per 40 ms.
- wheelPxPerZoomLevel (number; optional): How many scroll pixels (as reported by L.DomEvent.getWheelDelta) mean a change
of one full zoom level. Smaller values will make wheel-zooming faster (and vice 
versa).
- tapTolerance (number; optional): The max number of pixels a user can shift his finger during touch for it to 
be considered a valid tap.
- bounceAtZoomLimits (boolean; optional): Set it to false if you don't want the map to zoom beyond min/max zoom and then 
bounce back when pinch-zooming.
- id (string; optional): The ID used to identify this component in Dash callbacks (dynamic)
- style (dict; default {'width': "100%", 'height': "100%", "position": "relative"}): The CSS style of the component (dynamic)
- className (string; optional): The class name of the component (dynamic)
- attribution (string; optional): The attribution string for the component (dynamic)
- click_lat_lng (list of numbers; optional): Dash callback property. Receives [lat, lng] upon click.
- dbl_click_lat_lng (list of numbers; optional): Dash callback property. Receives [lat, lng] upon double click.
- location_lat_lon_acc (list of numbers; optional): Dash callback property. Receives [lat, lng, accuracy] when user location is found."""
    @_explicitize_args
    def __init__(self, children=None, animate=Component.UNDEFINED, duration=Component.UNDEFINED, easeLinearity=Component.UNDEFINED, noMoveStart=Component.UNDEFINED, bounds=Component.UNDEFINED, boundsOptions=Component.UNDEFINED, boxZoom=Component.UNDEFINED, center=Component.UNDEFINED, doubleClickZoom=Component.UNDEFINED, dragging=Component.UNDEFINED, keyboard=Component.UNDEFINED, maxBounds=Component.UNDEFINED, scrollWheelZoom=Component.UNDEFINED, useFlyTo=Component.UNDEFINED, tap=Component.UNDEFINED, touchZoom=Component.UNDEFINED, viewport=Component.UNDEFINED, zoom=Component.UNDEFINED, preferCanvas=Component.UNDEFINED, attributionControl=Component.UNDEFINED, zoomControl=Component.UNDEFINED, closePopupOnClick=Component.UNDEFINED, zoomSnap=Component.UNDEFINED, zoomDelta=Component.UNDEFINED, trackResize=Component.UNDEFINED, crs=Component.UNDEFINED, minZoom=Component.UNDEFINED, maxZoom=Component.UNDEFINED, renderer=Component.UNDEFINED, zoomAnimation=Component.UNDEFINED, zoomAnimationThreshold=Component.UNDEFINED, fadeAnimation=Component.UNDEFINED, markerZoomAnimation=Component.UNDEFINED, transform3DLimit=Component.UNDEFINED, inertia=Component.UNDEFINED, inertiaDeceleration=Component.UNDEFINED, inertiaMaxSpeed=Component.UNDEFINED, worldCopyJump=Component.UNDEFINED, maxBoundsViscosity=Component.UNDEFINED, keyboardPanDelta=Component.UNDEFINED, wheelDebounceTime=Component.UNDEFINED, wheelPxPerZoomLevel=Component.UNDEFINED, tapTolerance=Component.UNDEFINED, bounceAtZoomLimits=Component.UNDEFINED, id=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, attribution=Component.UNDEFINED, click_lat_lng=Component.UNDEFINED, dbl_click_lat_lng=Component.UNDEFINED, location_lat_lon_acc=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'animate', 'duration', 'easeLinearity', 'noMoveStart', 'bounds', 'boundsOptions', 'boxZoom', 'center', 'doubleClickZoom', 'dragging', 'keyboard', 'maxBounds', 'scrollWheelZoom', 'useFlyTo', 'tap', 'touchZoom', 'viewport', 'zoom', 'preferCanvas', 'attributionControl', 'zoomControl', 'closePopupOnClick', 'zoomSnap', 'zoomDelta', 'trackResize', 'crs', 'minZoom', 'maxZoom', 'renderer', 'zoomAnimation', 'zoomAnimationThreshold', 'fadeAnimation', 'markerZoomAnimation', 'transform3DLimit', 'inertia', 'inertiaDeceleration', 'inertiaMaxSpeed', 'worldCopyJump', 'maxBoundsViscosity', 'keyboardPanDelta', 'wheelDebounceTime', 'wheelPxPerZoomLevel', 'tapTolerance', 'bounceAtZoomLimits', 'id', 'style', 'className', 'attribution', 'click_lat_lng', 'dbl_click_lat_lng', 'location_lat_lon_acc']
        self._type = 'Map'
        self._namespace = 'dash_leaflet'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'animate', 'duration', 'easeLinearity', 'noMoveStart', 'bounds', 'boundsOptions', 'boxZoom', 'center', 'doubleClickZoom', 'dragging', 'keyboard', 'maxBounds', 'scrollWheelZoom', 'useFlyTo', 'tap', 'touchZoom', 'viewport', 'zoom', 'preferCanvas', 'attributionControl', 'zoomControl', 'closePopupOnClick', 'zoomSnap', 'zoomDelta', 'trackResize', 'crs', 'minZoom', 'maxZoom', 'renderer', 'zoomAnimation', 'zoomAnimationThreshold', 'fadeAnimation', 'markerZoomAnimation', 'transform3DLimit', 'inertia', 'inertiaDeceleration', 'inertiaMaxSpeed', 'worldCopyJump', 'maxBoundsViscosity', 'keyboardPanDelta', 'wheelDebounceTime', 'wheelPxPerZoomLevel', 'tapTolerance', 'bounceAtZoomLimits', 'id', 'style', 'className', 'attribution', 'click_lat_lng', 'dbl_click_lat_lng', 'location_lat_lon_acc']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Map, self).__init__(children=children, **args)



import json
import os
import pathlib

from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

with open(os.path.join('dash_leaflet', 'package.json')) as f:
    package = json.load(f)

package_name = package["name"].replace(" ", "_").replace("-", "_")

setup(
    name=package_name,
    version=package["version"],
    author=package['author'],
    author_email="emil.h.eriksen@gmail.com",
    packages=[package_name],
    include_package_data=True,
    license=package['license'],
    description=package['description'] if 'description' in package else package_name,
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/thedirtyfew/dash-leaflet",
    install_requires=[]
)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class ImageOverlay(Component):
    """An ImageOverlay component.
ImageOverlay is a wrapper of ImageOverlay in react-leaflet.
It takes similar properties to its react-leaflet counterpart.

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): The children of this component
- url (string; required): The URL of the image
- bounds (list of list of numberss; required): The geographical bounds the image is tied to.
- opacity (number; optional): The opacity of the image overlay.
- zIndex (number; optional): The explicit zIndex of the overlay layer.
- alt (string; optional): Text for the alt attribute of the image (useful for accessibility).
- interactive (boolean; optional): If true, the image overlay will emit mouse events when clicked or hovered.
- bubblingMouseEvents (boolean; optional): When true, a mouse event on this path will trigger the same 
event on the map (unless L.DomEvent.stopPropagation is used).
- crossOrigin (boolean; optional): Whether the crossOrigin attribute will be added to the image. If 
a String is provided, the image will have its crossOrigin attribute 
set to the String provided. This is needed if you want to access image 
pixel data. Refer to CORS Settings for valid String values.
- errorOverlayUrl (string; optional): URL to the overlay image to show in place of the overlay that failed to load.
- className (string; optional): A custom class name to assign to the image. Empty by default.
- id (string; optional): The ID used to identify this component in Dash callbacks
- pane (string; optional): The leaflet pane of the component
- attribution (string; optional): The attribution string for the component (dynamic)
- click_lat_lng (list of numbers; optional): Dash callback property. Receives [lat, lng] upon click. Requires interactive=True.
- dbl_click_lat_lng (list of numbers; optional): Dash callback property. Receives [lat, lng] upon double click. Requires interactive=True."""
    @_explicitize_args
    def __init__(self, children=None, url=Component.REQUIRED, bounds=Component.REQUIRED, opacity=Component.UNDEFINED, zIndex=Component.UNDEFINED, alt=Component.UNDEFINED, interactive=Component.UNDEFINED, bubblingMouseEvents=Component.UNDEFINED, crossOrigin=Component.UNDEFINED, errorOverlayUrl=Component.UNDEFINED, className=Component.UNDEFINED, id=Component.UNDEFINED, pane=Component.UNDEFINED, attribution=Component.UNDEFINED, click_lat_lng=Component.UNDEFINED, dbl_click_lat_lng=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'url', 'bounds', 'opacity', 'zIndex', 'alt', 'interactive', 'bubblingMouseEvents', 'crossOrigin', 'errorOverlayUrl', 'className', 'id', 'pane', 'attribution', 'click_lat_lng', 'dbl_click_lat_lng']
        self._type = 'ImageOverlay'
        self._namespace = 'dash_leaflet'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'url', 'bounds', 'opacity', 'zIndex', 'alt', 'interactive', 'bubblingMouseEvents', 'crossOrigin', 'errorOverlayUrl', 'className', 'id', 'pane', 'attribution', 'click_lat_lng', 'dbl_click_lat_lng']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['url', 'bounds']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(ImageOverlay, self).__init__(children=children, **args)



from .Circle import Circle
from .CircleMarker import CircleMarker
from .Colorbar import Colorbar
from .DivMarker import DivMarker
from .GeoJSON import GeoJSON
from .GeoTIFFOverlay import GeoTIFFOverlay
from .ImageOverlay import ImageOverlay
from .LayerGroup import LayerGroup
from .LocateControl import LocateControl
from .Map import Map
from .Marker import Marker
from .Pane import Pane
from .Polygon import Polygon
from .Polyline import Polyline
from .PolylineDecorator import PolylineDecorator
from .Popup import Popup
from .Rectangle import Rectangle
from .SVGOverlay import SVGOverlay
from .ScaleControl import ScaleControl
from .TileLayer import TileLayer
from .Tooltip import Tooltip
from .VideoOverlay import VideoOverlay
from .WMSTileLayer import WMSTileLayer

__all__ = [
    "Circle",
    "CircleMarker",
    "Colorbar",
    "DivMarker",
    "GeoJSON",
    "GeoTIFFOverlay",
    "ImageOverlay",
    "LayerGroup",
    "LocateControl",
    "Map",
    "Marker",
    "Pane",
    "Polygon",
    "Polyline",
    "PolylineDecorator",
    "Popup",
    "Rectangle",
    "SVGOverlay",
    "ScaleControl",
    "TileLayer",
    "Tooltip",
    "VideoOverlay",
    "WMSTileLayer"
]


# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class ScaleControl(Component):
    """A ScaleControl component.
ScaleControl is a wrapper of ScaleControl in react-leaflet.
It takes similar properties to its react-leaflet counterpart.

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): The children of this component (dynamic).
- imperial (boolean; optional): Imperial scale or not.
- metric (boolean; optional): Metric scale or not.
- updateWhenIdle (boolean; optional): Update when idle or not.
- maxWidth (number; optional): Control maxWidth.
- className (string; optional): A custom class name to assign to the image. Empty by default.
- id (string; optional): The ID used to identify this component in Dash callbacks."""
    @_explicitize_args
    def __init__(self, children=None, imperial=Component.UNDEFINED, metric=Component.UNDEFINED, updateWhenIdle=Component.UNDEFINED, maxWidth=Component.UNDEFINED, className=Component.UNDEFINED, id=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'imperial', 'metric', 'updateWhenIdle', 'maxWidth', 'className', 'id']
        self._type = 'ScaleControl'
        self._namespace = 'dash_leaflet'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'imperial', 'metric', 'updateWhenIdle', 'maxWidth', 'className', 'id']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(ScaleControl, self).__init__(children=children, **args)
